InitCategory class
Constructors
Properties
- depth → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- image → String?
-
final
- name → String
-
final
- ordinary → int?
-
final
- parentPrimary → int?
-
final
- primary → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
makeMap(
) → Map< String, dynamic> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
loadMap(
Map< String, dynamic> doc, String id) → InitCategory